======================
CRDB Python frontend
======================

|CRDB|

|docs| |github-ci| |codecov| |version| |wheel| |supported-versions| |supported-implementations|

Official website of the CRDB with online-viewer and documentation: https://lpsc.in2p3.fr/crdb.

.. start-badges

.. |docs| image:: https://readthedocs.org/projects/crdb/badge/?style=flat
    :target: https://crdb.readthedocs.io/
    :alt: Documentation Status

.. |github-ci| image:: https://github.com/crdb-project/crdb/actions/workflows/test.yml/badge.svg
    :alt: Foo
    :target: https://github.com/crdb-project/crdb/actions/workflows/test.yml

.. |codecov| image:: https://codecov.io/gh/crdb-project/crdb/branch/main/graphs/badge.svg?branch=main
    :alt: Coverage Status
    :target: https://codecov.io/github/crdb-project/crdb

.. |version| image:: https://img.shields.io/pypi/v/crdb.svg
    :alt: PyPI Package latest release
    :target: https://pypi.org/project/crdb

.. |wheel| image:: https://img.shields.io/pypi/wheel/crdb.svg
    :alt: PyPI Wheel
    :target: https://pypi.org/project/crdb

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/crdb.svg
    :alt: Supported versions
    :target: https://pypi.org/project/crdb

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/crdb.svg
    :alt: Supported implementations
    :target: https://pypi.org/project/crdb


.. end-badges


Installation
============

::

    pip install crdb

You can install the in-development version with::

    pip install https://github.com/crdb-project/crdb/archive/main.zip


.. |CRDB| image:: https://lpsc.in2p3.fr/crdb/img/crdb_logo.svg
    :target: https://lpsc.in2p3.fr/crdb